==> modx-2.0.6-pl-ja.zip: modx-2.0.6-pl-ja/core/lexicon/ja/snippet.inc.php <==
<?php
/**
 * Snippet Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['snippet'] = 'スニペット';
$_lang['snippets_available'] = 'スニペットはページ中にコールを記述して呼び出すことができます。';
$_lang['snippet_code'] = 'スニペットコード(php)';
$_lang['snippet_delete_confirm'] = 'このスニペットを削除しますか？';
$_lang['snippet_desc'] = '説明';
$_lang['snippet_duplicate_confirm'] = 'このスニペットを複製しますか？';
$_lang['snippet_duplicate_error'] = 'スニペットの複製中にエラーが発生しました。';
$_lang['snippet_err_create'] = 'スニペットの作成中にエラーが発生しました。';
$_lang['snippet_err_delete'] = 'スニペットの削除中にエラーが発生しました。';
$_lang['snippet_err_duplicate'] = 'スニペットの複製中にエラーが発生しました。';
$_lang['snippet_err_exists_name'] = '[[+name]]という名前のスニペットがすでに存在します。';
$_lang['snippet_err_invalid_name'] = '無効なスニペット名です。';
$_lang['snippet_err_locked'] = 'このスニペットは編集中のためロックされています。';
$_lang['snippet_err_nf'] = 'スニペットが見つかりません';
$_lang['snippet_err_ns'] = 'スニペットが指定されていません。';
$_lang['snippet_err_ns_name'] = 'スニペットの名前を指定してください。';
$_lang['snippet_err_remove'] = 'スニペットの削除中にエラーが発生しました。';
$_lang['snippet_err_save'] = 'スニペットの保存中にエラーが発生しました。';
$_lang['snippet_execonsave'] = '保存後にスニペットを実行';
$_lang['snippet_lock'] = '編集のためスニペットをロックする';
$_lang['snippet_lock_msg'] = 'スニペットを編集するためにはロックの解除が必要です。';
$_lang['snippet_management_msg'] = '<h3 style="font-weight:bold;">スニペットの管理</h3><p>編集したいスニペットを選択してください。</p>';
$_lang['snippet_msg'] = 'スニペットを追加・編集することができます。先頭と末尾の「&lt;?php」「?&gt;」は必須です。省略した場合は自動的に追加されます。';
$_lang['snippet_name'] = 'スニペット名';
$_lang['snippet_new'] = '新規スニペット';
$_lang['snippet_properties'] = '既定のプロパティ';
$_lang['snippet_title'] = 'スニペットの作成/編集';
$_lang['snippet_untitled'] = '無名のスニペット';
$_lang['snippets'] = 'スニペット';

==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/ja/snippet.inc.php <==
<?php
/**
* Snippet Japanese lexicon topic
*
* @language ja
* @package modx
* @subpackage lexicon
* @author Nick http://smallworld.west-tokyo.com
* @author shimojo http://www.priqia.com/
* @author yamamoto http://kyms.jp
* @author honda http://kogus.org
*/
$_lang['snippet'] = 'スニペット';
$_lang['snippets_available'] = 'スニペットはページ中にコールを記述して呼び出すことができます。';
$_lang['snippet_code'] = 'スニペットコード(php)';
$_lang['snippet_delete_confirm'] = 'このスニペットを削除しますか？';
$_lang['snippet_desc'] = '説明';
$_lang['snippet_desc_category'] = 'このスニペットが属するカテゴリー';
$_lang['snippet_desc_description'] = 'スニペットの概要';
$_lang['snippet_desc_name'] = 'このスニペットの名前です。ここで指定した名前は、[[名前]]という表記で利用されます。';
$_lang['snippet_duplicate_confirm'] = 'このスニペットを複製しますか？';
$_lang['snippet_duplicate_error'] = 'スニペットの複製中にエラーが発生しました。';
$_lang['snippet_err_create'] = 'スニペットの作成中にエラーが発生しました。';
$_lang['snippet_err_delete'] = 'スニペットの削除中にエラーが発生しました。';
$_lang['snippet_err_duplicate'] = 'スニペットの複製中にエラーが発生しました。';
$_lang['snippet_err_exists_name'] = '[[+name]]という名前のスニペットがすでに存在します。';
$_lang['snippet_err_invalid_name'] = '無効なスニペット名です。';
$_lang['snippet_err_locked'] = 'このスニペットは編集中のためロックされています。';
$_lang['snippet_err_nf'] = 'スニペットが見つかりません';
$_lang['snippet_err_ns'] = 'スニペットが指定されていません。';
$_lang['snippet_err_ns_name'] = 'スニペットの名前を指定してください。';
$_lang['snippet_err_remove'] = 'スニペットの削除中にエラーが発生しました。';
$_lang['snippet_err_save'] = 'スニペットの保存中にエラーが発生しました。';
$_lang['snippet_execonsave'] = '保存後にスニペットを実行';
$_lang['snippet_lock'] = '編集のためスニペットをロックする';
$_lang['snippet_lock_msg'] = 'スニペットを編集するためにはロックの解除が必要です。';
$_lang['snippet_management_msg'] = '<h3 style="font-weight:bold;">スニペットの管理</h3><p>編集したいスニペットを選択してください。</p>';
$_lang['snippet_msg'] = 'スニペットを追加・編集することができます。先頭と末尾の「&lt;?php」「?&gt;」は必須です。省略した場合は自動的に追加されます。';
$_lang['snippet_name'] = 'スニペット名';
$_lang['snippet_new'] = '新規スニペット';
$_lang['snippet_properties'] = '既定のプロパティ';
$_lang['snippet_title'] = 'スニペットの作成/編集';
$_lang['snippet_untitled'] = '無名のスニペット';
$_lang['snippets'] = 'スニペット';
